package sk.upjs.js;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.jdbc.core.namedparam.BeanPropertySqlParameterSource;
import org.springframework.jdbc.core.simple.ParameterizedBeanPropertyRowMapper;
import org.springframework.jdbc.core.simple.SimpleJdbcInsert;
import org.springframework.jdbc.core.simple.SimpleJdbcTemplate;
import org.springframework.orm.hibernate3.HibernateTemplate;
import org.springframework.stereotype.Component;

@Component
public class Database {
	@Autowired
	private HibernateTemplate hibernateTemplate;

	/**
	 * Vrti zoznam vetkch tudentov v databze. 
	 */
	public List<Student> listStudents() {
		return hibernateTemplate.find("from Student"); 
	}

	/**
	 * Njde v databze tudenta s danm identifiktorom. Ak
	 * sa tak tudent nenjde, vrti <code>null</code>.
	 */
	public Student findById(Integer id) {
		return (Student) hibernateTemplate.get(Student.class, id);
	}

	/**
	 * Ulo alebo aktualizuje objekt tudenta. Ak m tudent
	 * identifiktor rovn <code>null</code>, znamen
	 * to intanciu, ktor v databze ete nie je. V opanom 
	 * prpade sa existujca intancia s takm ID nahrad
	 * novou intanciou s aktualizovanmi dtami. 
	 * 
	 * @param student
	 */
	public void saveOrUpdate(Student student) {
		hibernateTemplate.saveOrUpdate(student);
	}

	/**
	 * Odstrni z databzy tudenta s danm identifiktorom.
	 * Intancia v parametri nemus ma vyplnen vetky daje, sta,
	 * ke m vyplnen identifiktor.
	 */ 
	public void removeStudent(Student student) {
		hibernateTemplate.delete(student);
	}

	public void setHibernateTemplate(HibernateTemplate hibernateTemplate) {
		this.hibernateTemplate = hibernateTemplate;
	}

	
	
}
